
#secuuth-python-sdk
IT Takes token as input and it verify ,decode and renew the token


##Installation

```pip install secuuthTokenPythonSdk```

##Methods
decodedAndVerifiedAccessToken=accessToken(token).decode()
decodedAndVerifiedIdToken=accessToken(token).decode()